// cases.js

/**
 * Convert array of words to camelCase
 * Example: ["my", "variable", "name"] -> "myVariableName"
 * Handle acronyms: If a word is uppercase and handleAcronyms is true, it should remain uppercase.
 */
export function toCamelCase(words) {
    if (!words.length) return '';
    return words
      .map((word, i) => {
        if (i === 0) return word.toLowerCase();
        return word.charAt(0).toUpperCase() + word.slice(1);
      })
      .join('');
  }
  
  /**
   * Convert array of words to PascalCase
   * Example: ["my", "variable", "name"] -> "MyVariableName"
   */
  export function toPascalCase(words) {
    return words
      .map((word) => word.charAt(0).toUpperCase() + word.slice(1))
      .join('');
  }
  
  /**
   * Convert array of words to snake_case
   * Example: ["my", "variable", "name"] -> "my_variable_name"
   */
  export function toSnakeCase(words) {
    return words.map((w) => w.toLowerCase()).join('_');
  }
  
  /**
   * Convert array of words to kebab-case
   * Example: ["my", "variable", "name"] -> "my-variable-name"
   */
  export function toKebabCase(words) {
    return words.map((w) => w.toLowerCase()).join('-');
  }
  