// index.js
import { splitIntoWords, handleAcronymsInWords } from './utils.js';
import { toCamelCase, toPascalCase, toSnakeCase, toKebabCase } from './cases.js';

/**
 * Convert a given string from any known format into a target format.
 * @param {string} str - The input string.
 * @param {string} toCase - The target case: "camel", "pascal", "snake", or "kebab".
 * @param {object} options - { handleAcronyms: boolean }
 * @returns {string} The converted string.
 */
export function convertCase(str, toCase, options = {}) {
  const words = splitIntoWords(str);
  const normalizedWords = handleAcronymsInWords(words, options);

  switch (toCase) {
    case 'camel':
      return toCamelCase(normalizedWords);
    case 'pascal':
      return toPascalCase(normalizedWords);
    case 'snake':
      return toSnakeCase(normalizedWords);
    case 'kebab':
      return toKebabCase(normalizedWords);
    default:
      throw new Error(`Invalid case: ${toCase}`);
  }
}
